@@ -37,7 +37,7 @@ class GeneratePage : public QWizardPage
     Q_OBJECT
 
 public:
-    GeneratePage(QWidget *parent = 0);
+    explicit GeneratePage(QWidget *parent = nullptr);
 
 private:
     Ui::generate ui_generate;
@@ -45,7 +45,7 @@ private:
     bool unpackArchive(const KArchiveDirectory *dir, const QString &dest, const QStringList& skipList = QStringList());
     bool extractFileMacros(const QString &entry);
 
-    void initializePage();
+    void initializePage() override;
     void displayError(const QString &error);
 
     QString templateName;
